import pino = require('pino');
import Sentry = require('raven');
import redisLib = require('redis');
import {queue, queueReady} from '../components/queue';

const redis = redisLib.createClient();

const SENTRY_DSN = process.env.SENTRY_DSN;
Sentry.config(SENTRY_DSN).install();
export const sentry = Sentry;

export const logger = pino();

interface ErrorDescription {
    message?: string;
    extra?: object;
    tags?: {[key: string]: string};
}

export function log(message: string, args?: object): void {
    if (args) {
        logger.info(args, message);
    } else {
        logger.info(message);
    }
}

export function reportError(error: Error, args?: ErrorDescription): void {
    const callArgs: Array<Error | string | object> = [error];
    if (args) {
        if (args.message) {
            callArgs.push(args.message);
        }
        if (args.extra) {
            callArgs.push(args.extra);
        }
    }
    (logger.error as any)(...callArgs);
    sentry.captureException(error, args);
}

export function logToDiscord(message: string): void {
    log(`[DiscordLogger] ${message}`);
    redis.publish('discordLog', message);
}

export async function enqueue(task: string, args: Array<string | number>, queueName: string = 'common'): Promise<any> {
    await queueReady;
    return queue.publish(queueName, {task, args});
}

interface PlainObject {
    [key: string]: any;
}

export function clearNulls(input: PlainObject): PlainObject {
    return Object.keys(input).reduce((acc: PlainObject, current) => {
        if (input[current] !== null) {
            acc[current] = input[current];
        }
        return acc;
    }, {});
}
