import path = require('path');
import {queue} from '../components/queue';
import {log, reportError} from './utils';

const runnerPath = path.resolve(__dirname, '../', 'components/task-runner.js');

interface AppTask {
    data: {
        task: string;
        args: any;
    };
}

function taskRunner(job: AppTask): Promise<any> {
    return require(`../tasks/${job.data.task}`)(...job.data.args);
}

async function processQueue(job: AppTask): Promise<any> {
    try {
        await taskRunner(job);
    } catch (error) {
        reportError(error, {extra: {job}});
    }
}

export default async function runWorker(): Promise<any> {
    log('Initiating worker master process');
    await queue.start().catch(reportError);
    queue.subscribe('common', {teamConcurrency: 2}, processQueue);
    queue.subscribe('import', {teamConcurrency: 4}, processQueue);
    queue.subscribe('critical', {teamConcurrency: 1}, processQueue);
}
