"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const queue_1 = require("../components/queue");
const utils_1 = require("./utils");
const runnerPath = path.resolve(__dirname, '../', 'components/task-runner.js');
function taskRunner(job) {
    return require(`../tasks/${job.data.task}`)(...job.data.args);
}
async function processQueue(job) {
    try {
        await taskRunner(job);
    }
    catch (error) {
        utils_1.reportError(error, { extra: { job } });
    }
}
async function runWorker() {
    utils_1.log('Initiating worker master process');
    await queue_1.queue.start().catch(utils_1.reportError);
    queue_1.queue.subscribe('common', { teamConcurrency: 2 }, processQueue);
    queue_1.queue.subscribe('import', { teamConcurrency: 4 }, processQueue);
    queue_1.queue.subscribe('critical', { teamConcurrency: 1 }, processQueue);
}
exports.default = runWorker;
//# sourceMappingURL=worker.js.map